DmChartPalette class

Theme-derived defaults for DuskMoon visualization wrappers.

Constructors

DmChartPalette({required Color background, required Color grid, required Color axis, required Color primary, required Color secondary, required Color positive, required Color positiveOnColor, required Color warning, required Color warningOnColor, required Color heatmapBorder})
const
DmChartPalette.fromTheme(ThemeData theme)
factory

Properties

axis Color
final
background Color
final
grid Color
final
hashCode int
The hash code for this object.
no setterinherited
heatmapBorder Color
final
positive Color
final
positiveOnColor Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
warning Color
final
warningOnColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited