DmVizNetworkNode class

Public data model for a DuskMoon network node.

Constructors

DmVizNetworkNode({required String id, String? label, String? group, double? x, double? y, bool fixed = false, double radius = 10, Color? color, Map<String, dynamic>? metadata})
const

Properties

color Color?
final
fixed bool
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String?
final
metadata Map<String, dynamic>?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double?
final
y double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRaw() NetworkNode
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited