AnnotationConfig class

Base configuration for annotations.

Implementers

Constructors

AnnotationConfig({Color color = const Color(0xFF666666), double strokeWidth = 1, List<double>? dashPattern})
Creates an annotation configuration.
const

Properties

color Color
The color of the annotation.
final
dashPattern List<double>?
The dash pattern for line annotations. If null, solid lines are drawn.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
The stroke width for line annotations.
final

Methods

copyWith({Color? color, double? strokeWidth, List<double>? dashPattern}) AnnotationConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited