Arc class

A widget that draws an arc shape for pie/donut chart slices.

Inheritance
Available extensions

Constructors

Arc({Key? key, double centerX = 0, double centerY = 0, required double outerRadius, double innerRadius = 0, required double startAngle, required double endAngle, Color color = const Color(0xFF000000), Color? strokeColor, double strokeWidth = 1.0, double cornerRadius = 0, double padAngle = 0, Shader? shader})
Creates an arc widget.
const

Properties

centerX double
The center x coordinate.
final
centerY double
The center y coordinate.
final
centroid Offset

Available on Arc, provided by the ArcGeometry extension

Calculates the centroid point of the arc.
no setter
color Color
The fill color.
final
cornerRadius double
Optional corner radius for rounded corners.
final
endAngle double
The end angle in radians.
final
hashCode int
The hash code for this object.
no setterinherited
innerRadius double
The inner radius (0 for pie slice, > 0 for donut slice).
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
outerRadius double
The outer radius.
final
padAngle double
Optional padding angle in radians between slices.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shader Shader?
Optional gradient shader.
final
startAngle double
The start angle in radians.
final
strokeColor Color?
Optional stroke color for the outline.
final
strokeWidth double
The stroke width for the outline.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited