AreaPath class

A widget that draws a filled area between two lines or from a baseline.

Inheritance

Constructors

AreaPath({Key? key, required List<Point> points, List<Point>? bottomPoints, double baseline = 0, Curve? curve, Color color = const Color(0x80000000), Color? strokeColor, double strokeWidth = 1.0, Shader? shader, bool defined(Point)?})
Creates an area path widget.
const

Properties

baseline double
The baseline y-value when bottomPoints is null.
final
bottomPoints List<Point>?
Optional data points for the bottom line. If null, uses baseline.
final
color Color
The fill color.
final
curve Curve?
Optional curve generator for smooth areas.
final
defined bool Function(Point)?
Whether the line is defined (drawn) for null/invalid points.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
points List<Point>
The data points for the top line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shader Shader?
Optional gradient shader.
final
strokeColor Color?
Optional stroke color for the outline.
final
strokeWidth double
The stroke width for the outline.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited