ArgbColor class

A simple ARGB color representation for pure Dart usage.

Constructors

ArgbColor(int alpha, int red, int green, int blue)
const
ArgbColor.fromARGB(int a, int r, int g, int b)
Creates a color from a 32-bit ARGB value.
factory
ArgbColor.fromValue(int value)
Creates a color from a 32-bit integer value (0xAARRGGBB format).
factory

Properties

alpha int
final
blue int
final
green int
final
hashCode int
The hash code for this object.
no setteroverride
red int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Returns the color as a 32-bit integer value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override