AxisLineConfig class

Configuration for the axis line.

Constructors

AxisLineConfig({bool visible = true, double strokeWidth = 1, Color color = const Color(0xFF000000)})
Creates an axis line configuration.
const

Properties

color Color
The color of the axis line.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
The stroke width of the axis line.
final
visible bool
Whether to show the axis line.
final

Methods

copyWith({bool? visible, double? strokeWidth, Color? color}) AxisLineConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited