AxisOrientation enum

The orientation of an axis.

Inheritance
Available extensions

Values

bottom → const AxisOrientation

Axis at the bottom of the chart (horizontal, labels below).

top → const AxisOrientation

Axis at the top of the chart (horizontal, labels above).

left → const AxisOrientation

Axis at the left of the chart (vertical, labels to the left).

Axis at the right of the chart (vertical, labels to the right).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AxisOrientation>
A constant List of the values in this enum, in order of their declaration.