AxisTick<T> class
A tick value with its position and label.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The label to display for this tick.
final
- position → double
-
The position of this tick in pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The domain value for this tick.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited