call method
Returns the start position of the band for the given value.
Implementation
double call(T value) {
final index = _domain.indexOf(value);
if (index < 0) return double.nan;
return _bandStart(index);
}
Returns the start position of the band for the given value.
double call(T value) {
final index = _domain.indexOf(value);
if (index < 0) return double.nan;
return _bandStart(index);
}