BarSeries class

Bar series for XY charts.

Inheritance

Constructors

BarSeries({Key? key, required List<XYDataPoint> data, Color color = Colors.blue, Color? borderColor, double borderWidth = 0, double barWidth = 0.8, double cornerRadius = 0, bool horizontal = false, void onBarTap(XYDataPoint point, int index)?})
const

Properties

barWidth double
Bar width as a fraction of available space (0-1).
final
borderColor Color?
Bar border color.
final
borderWidth double
Bar border width.
final
color Color
Bar fill color.
final
cornerRadius double
Corner radius for rounded bars.
final
data List<XYDataPoint>
Data points for the bars.
final
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
Whether bars are horizontal.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBarTap → void Function(XYDataPoint point, int index)?
Callback when a bar is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited