BoundingBoxForce class

Force that constrains nodes within a bounding box.

Inheritance

Constructors

BoundingBoxForce({required double minX, required double minY, required double maxX, required double maxY, double bounce = 0.5})

Properties

bounce double
final
hashCode int
The hash code for this object.
no setterinherited
maxX double
final
maxY double
final
minX double
final
minY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(ForceSimulation simulation) → void
Applies the force to the simulation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited