Brush2DState enum
The state of a 2D brush selection.
Values
- idle → const Brush2DState
-
No brush selection is active.
- brushing → const Brush2DState
-
A brush selection is being created.
- moving → const Brush2DState
-
A brush selection is being moved.
- resizingTopLeft → const Brush2DState
-
A brush selection is being resized from the top-left.
- resizingTopRight → const Brush2DState
-
A brush selection is being resized from the top-right.
- resizingBottomLeft → const Brush2DState
-
A brush selection is being resized from the bottom-left.
- resizingBottomRight → const Brush2DState
-
A brush selection is being resized from the bottom-right.
- resizingTop → const Brush2DState
-
A brush selection is being resized from the top.
- resizingBottom → const Brush2DState
-
A brush selection is being resized from the bottom.
- resizingLeft → const Brush2DState
-
A brush selection is being resized from the left.
- resizingRight → const Brush2DState
-
A brush selection is being resized from the right.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Brush2DState> - A constant List of the values in this enum, in order of their declaration.