BrushExtent class

The extent of a brush selection.

Constructors

BrushExtent(double start, double end)
Creates a BrushExtent.
const

Properties

end double
The end value of the selection.
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Whether the selection is empty.
no setter
max double
The maximum value of the selection.
no setter
min double
The minimum value of the selection.
no setter
normalized BrushExtent
Returns a normalized extent where start <= end.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the selection.
no setter
start double
The start value of the selection.
final

Methods

clamp(double minBound, double maxBound) BrushExtent
Clamps the extent to the given bounds.
contains(double value) bool
Whether a value is within the selection.
copyWith({double? start, double? end}) BrushExtent
Creates a copy with updated values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

empty → const BrushExtent
Creates an empty extent.