BrushState enum

The state of a brush selection.

Inheritance
Available extensions

Values

idle → const BrushState

No brush selection is active.

brushing → const BrushState

A brush selection is being created.

moving → const BrushState

A brush selection is being moved.

resizingStart → const BrushState

A brush selection is being resized from the start.

resizingEnd → const BrushState

A brush selection is being resized from the end.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BrushState>
A constant List of the values in this enum, in order of their declaration.