BubbleDataPoint class
Data point for bubble charts with a size value.
- Inheritance
-
- Object
- XYDataPoint
- BubbleDataPoint
Constructors
-
BubbleDataPoint({required dynamic x, required double y, required double size, Map<
String, dynamic> ? metadata}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited