CalendarHeatmap class

Calendar heatmap for showing values over time.

Inheritance

Constructors

CalendarHeatmap({Key? key, required Map<DateTime, double> data, required DateTime startDate, required DateTime endDate, required double minValue, required double maxValue, Color emptyColor = const Color(0xFFEBEDF0), Color startColor = const Color(0xFF9BE9A8), Color endColor = const Color(0xFF216E39), double cellSize = 12, double cellPadding = 2, double cellRadius = 2, bool showMonthLabels = true, bool showDayLabels = true, void onCellTap(DateTime date, double? value)?})
const

Properties

cellPadding double
Cell padding.
final
cellRadius double
Cell corner radius.
final
cellSize double
Cell size.
final
data Map<DateTime, double>
Map of date to value.
final
emptyColor Color
Color for empty cells.
final
endColor Color
End color for gradient.
final
endDate DateTime
End date of the calendar.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue double
Maximum value for color scale.
final
minValue double
Minimum value for color scale.
final
onCellTap → void Function(DateTime date, double? value)?
Callback when a cell is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDayLabels bool
Whether to show day labels.
final
showMonthLabels bool
Whether to show month labels.
final
startColor Color
Start color for gradient.
final
startDate DateTime
Start date of the calendar.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited