CenterForce class

Force that pushes nodes toward a center point.

Inheritance

Constructors

CenterForce({double x = 0, double y = 0, double strength = 1})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
final
x double
final
y double
final

Methods

apply(ForceSimulation simulation) → void
Applies the force to the simulation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited