chartPosition property
The position of the pointer in chart data coordinates. This is the position after any coordinate transformation.
Implementation
final Offset chartPosition;
The position of the pointer in chart data coordinates. This is the position after any coordinate transformation.
final Offset chartPosition;