CircleClip class

A circular clip widget.

Inheritance

Constructors

CircleClip({Key? key, required double centerX, required double centerY, required double radius, required Widget child, Clip clipBehavior = Clip.antiAlias})
Creates a circular clip widget.
const
CircleClip.fromCenter(Offset center, double radius, {Key? key, required Widget child, Clip clipBehavior = Clip.antiAlias})
Creates a circular clip from an Offset center.
factory

Properties

centerX double
The center x coordinate.
final
centerY double
The center y coordinate.
final
child Widget
The child widget to clip.
final
clipBehavior Clip
The clip behavior.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius double
The radius of the clip circle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fill({Key? key, required Widget child, Clip clipBehavior = Clip.antiAlias}) Widget
Creates a circular clip that fills the parent.