ColorSchemes class

Standard categorical color schemes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const List<String>
Accent color scheme (8 colors).
category10 → const List<String>
Category10 color scheme (10 colors).
dark2 → const List<String>
Dark2 color scheme (8 colors).
paired → const List<String>
Paired color scheme (12 colors).
pastel1 → const List<String>
Pastel1 color scheme (9 colors).
pastel2 → const List<String>
Pastel2 color scheme (8 colors).
set1 → const List<String>
Set1 color scheme (9 colors).
set2 → const List<String>
Set2 color scheme (8 colors).
set3 → const List<String>
Set3 color scheme (12 colors).
tableau10 → const List<String>
Tableau10 color scheme (10 colors).