CrossHatchPattern class

A cross-hatch pattern (two sets of lines).

Inheritance

Constructors

CrossHatchPattern({double strokeWidth = 1, double spacing = 8, double angle1 = 0.7853981633974483, double angle2 = -0.7853981633974483, Color backgroundColor = const Color(0x00000000), Color foregroundColor = const Color(0xFF000000)})
Creates a cross-hatch pattern.
const

Properties

angle1 double
The angle of the first set of lines.
final
angle2 double
The angle of the second set of lines.
final
backgroundColor Color
The background color.
finalinherited
foregroundColor Color
The foreground/pattern color.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double
The pattern height.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
The spacing between lines.
final
strokeWidth double
The line stroke width.
final
width double
The pattern width.
finalinherited

Methods

createShader(Rect bounds) Shader
Creates a shader that tiles this pattern.
inherited
drawPattern(Canvas canvas, Size size) → void
Draws the pattern once at origin.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited