CurveBasisOpen class

A basis spline curve that passes through endpoints.

Implemented types

Constructors

CurveBasisOpen()

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Returns true if this curve is closed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(List<Point> points) List<Point>
Generates curve points from the given data points.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited