CurveCardinal class
A cardinal spline curve with adjustable tension.
- Implemented types
Constructors
- CurveCardinal({double tension = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Returns true if this curve is closed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tension → double
-
The tension parameter (0 to 1). 0 = Catmull-Rom, 1 = linear.
final
Methods
-
generate(
List< Point> points) → List<Point> -
Generates curve points from the given data points.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited