CurveCatmullRom class
A Catmull-Rom spline curve with configurable alpha.
- Implemented types
Constructors
- CurveCatmullRom({double alpha = 0.5})
Properties
- alpha → double
-
The alpha parameter (0 = uniform, 0.5 = centripetal, 1 = chordal).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Returns true if this curve is closed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
List< Point> points) → List<Point> -
Generates curve points from the given data points.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited