DragDirection enum

Direction of allowed drag movement.

Inheritance
Available extensions

Values

horizontal → const DragDirection

Allow horizontal drag only.

vertical → const DragDirection

Allow vertical drag only.

both → const DragDirection

Allow drag in both directions.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

constrainDelta(Offset delta) Offset

Available on DragDirection, provided by the DragDirectionExtension extension

Constrains an offset to the allowed direction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DragDirection>
A constant List of the values in this enum, in order of their declaration.