DraggableWidget class

A widget that wraps its child with drag behavior.

Draggable provides a convenient way to make any widget draggable with customizable callbacks and constraints.

Inheritance

Constructors

DraggableWidget({Key? key, required Widget child, void onDragStart(DragState state)?, void onDragUpdate(DragState state)?, void onDragEnd(DragState state)?, void onDragCancel()?, bool enabled = true, DragDirection direction = DragDirection.both, DragConstraints? constraints, HitTestBehavior behavior = HitTestBehavior.deferToChild, Widget feedbackBuilder(BuildContext context, DragState state)?})
Creates a DraggableWidget.
const

Properties

behavior HitTestBehavior
The hit test behavior for the gesture detector.
final
child Widget
The child widget to make draggable.
final
constraints DragConstraints?
Constraints for the drag operation.
final
direction DragDirection
The direction of allowed drag movement.
final
enabled bool
Whether drag is enabled.
final
feedbackBuilder Widget Function(BuildContext context, DragState state)?
Optional feedback widget to show during drag.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragCancel → void Function()?
Called when a drag operation is cancelled.
final
onDragEnd → void Function(DragState state)?
Called when a drag operation ends.
final
onDragStart → void Function(DragState state)?
Called when a drag operation starts.
final
onDragUpdate → void Function(DragState state)?
Called when the drag position updates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DraggableWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited