ForceX class

Force that positions nodes along the x-axis based on a value.

Inheritance

Constructors

ForceX({double x = 0, double strength = 0.1})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
getter/setter pair
x double
final

Methods

apply(ForceSimulation simulation) → void
Applies the force to the simulation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited