GeoJsonFeature class
A GeoJSON Feature.
Constructors
-
GeoJsonFeature({GeoJsonGeometry? geometry, Map<
String, dynamic> properties = const {}, dynamic id}) -
GeoJsonFeature.fromJson(Map<
String, dynamic> json) -
factory
Properties
- geometry → GeoJsonGeometry?
-
The geometry of this feature.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → dynamic
-
Optional feature ID.
final
-
properties
→ Map<
String, dynamic> -
Properties associated with this feature.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited