GeoJsonGeometry class abstract

GeoJSON types and parsing utilities. A GeoJSON geometry object.

Implementers

Constructors

GeoJsonGeometry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of this geometry.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to a GeoJSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) GeoJsonGeometry?
Parses a GeoJSON geometry from a map.