GeoJsonGeometryCollection class
A GeoJSON GeometryCollection.
- Implemented types
Constructors
-
GeoJsonGeometryCollection(List<
GeoJsonGeometry> geometries) -
GeoJsonGeometryCollection.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
geometries
→ List<
GeoJsonGeometry> -
The geometries in this collection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of this geometry.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to a GeoJSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited