GeoView class

A widget that displays geographic data using a projection.

GeoView wraps a CustomPaint widget and renders geographic features using the provided projection and geoJson data.

Inheritance

Constructors

GeoView({Key? key, required Projection projection, required dynamic geoJson, Color? fillColor, Color? strokeColor, double strokeWidth = 1.0, void onFeatureTap(dynamic feature, Point position)?, bool antiAlias = true})
Creates a GeoView widget.
const

Properties

antiAlias bool
Whether to enable anti-aliasing.
final
fillColor Color?
The color to use for filling shapes.
final
geoJson → dynamic
The GeoJSON data to render.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFeatureTap → void Function(dynamic feature, Point position)?
Optional callback when a feature is tapped.
final
projection Projection
The projection to use for rendering.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color?
The color to use for stroking shapes.
final
strokeWidth double
The stroke width for shape outlines.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited