GradientStop class

A gradient stop with color and position.

Constructors

GradientStop(double offset, Color color)
Creates a gradient stop.
const
GradientStop.at(double offset, Color color)
Creates a gradient stop from offset and color.
factory

Properties

color Color
The color at this stop.
final
hashCode int
The hash code for this object.
no setterinherited
offset double
The position of this stop (0.0 - 1.0).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited