GraticuleConfig class
Configuration for graticule lines.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitudeStep → double
-
The step in degrees for latitude lines.
final
- longitudeStep → double
-
The step in degrees for longitude lines.
final
- maxLatitude → double
-
The maximum latitude to render.
final
- maxLongitude → double
-
The maximum longitude to render.
final
- minLatitude → double
-
The minimum latitude to render.
final
- minLongitude → double
-
The minimum longitude to render.
final
- precision → int
-
The precision of each line (number of points).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- coarse → const GraticuleConfig
- Creates a configuration with coarser grid lines.
- defaultConfig → const GraticuleConfig
- Default graticule configuration with 10 degree steps.
- fine → const GraticuleConfig
- Creates a configuration with finer grid lines.