GridRows class
Horizontal grid lines (rows) spanning the width of a chart.
GridRows renders horizontal lines at positions determined by a scale. These are typically used with a y-axis scale to show reference lines for values.
Example usage:
GridRows(
scale: scaleLinear(domain: [0, 100], range: [300, 0]),
width: 400,
height: 300,
tickCount: 5,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- Grid
- GridRows
Constructors
Properties
- config → GridConfig
-
Configuration for grid lines.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the grid area.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → dynamic
-
The scale used to determine grid line positions.
finalinherited
- tickCount → int
-
The number of grid lines to generate (if tickValues is not provided).
finalinherited
- tickValues → List?
-
Custom tick values for grid lines.
finalinherited
- width → double
-
The width of the grid area.
finalinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getPositions(
) → List< double> -
Returns the positions for grid lines.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited