Group class

A widget that groups child chart elements with optional transform and clip.

Inheritance

Constructors

Group({Key? key, required Widget child, Offset? translate, double? rotation, double? scale, Offset? scaleXY, Matrix4? transform, bool clip = false, Rect? clipRect, Path? clipPath, Clip clipBehavior = Clip.antiAlias, double? opacity})
Creates a group widget.
const

Properties

child Widget
The child widget to group.
final
clip bool
Whether to clip children to the group bounds.
final
clipBehavior Clip
The clip behavior when clipping.
final
clipPath Path?
Optional clip path when clip is true.
final
clipRect Rect?
Optional clip rect when clip is true.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity double?
Optional opacity for the group (0.0 - 1.0).
final
rotation double?
Optional rotation angle in radians.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
Optional uniform scale factor.
final
scaleXY Offset?
Optional scale factors for x and y axes.
final
transform Matrix4?
Optional custom transform matrix.
final
translate Offset?
Optional translation offset.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited