Heatmap class

Heatmap widget for visualizing matrix data.

Inheritance

Constructors

Heatmap({Key? key, required List<HeatmapDataPoint> data, required int rows, required int columns, required HeatmapColorScale colorScale, List<String>? rowLabels, List<String>? columnLabels, double cellPadding = 1, double cellRadius = 0, bool showValues = false, TextStyle? valueStyle, Color? borderColor, double borderWidth = 0, void onCellTap(HeatmapDataPoint point)?, void onCellHover(HeatmapDataPoint? point)?})
const

Properties

borderColor Color?
Cell border color.
final
borderWidth double
Cell border width.
final
cellPadding double
Cell padding.
final
cellRadius double
Cell corner radius.
final
colorScale HeatmapColorScale
Color scale configuration.
final
columnLabels List<String>?
Column labels.
final
columns int
Number of columns.
final
data List<HeatmapDataPoint>
Data points for the heatmap.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCellHover → void Function(HeatmapDataPoint? point)?
Callback when a cell is hovered.
final
onCellTap → void Function(HeatmapDataPoint point)?
Callback when a cell is tapped.
final
rowLabels List<String>?
Row labels.
final
rows int
Number of rows.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValues bool
Whether to show cell values.
final
valueStyle TextStyle?
Cell value text style.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Heatmap>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited