HeatmapCell class

Individual cell widget for heatmaps.

Inheritance

Constructors

HeatmapCell({Key? key, required Color color, double? value, double size = 40, double radius = 0, Color? borderColor, double borderWidth = 0, bool showValue = false, TextStyle? valueStyle, String valueFormat(double value)?, VoidCallback? onTap, void onHover(bool isHovered)?, String? tooltip})
const

Properties

borderColor Color?
Border color.
final
borderWidth double
Border width.
final
color Color
Cell fill color.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onHover → void Function(bool isHovered)?
Callback when cell is hovered.
final
onTap VoidCallback?
Callback when cell is tapped.
final
radius double
Corner radius.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValue bool
Whether to show the value text.
final
size double
Cell size.
final
tooltip String?
Tooltip content.
final
value double?
Cell value for display.
final
valueFormat String Function(double value)?
Value format function.
final
valueStyle TextStyle?
Value text style.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<HeatmapCell>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited