HeatmapColorScale class

Configuration for heatmap color scale.

Constructors

HeatmapColorScale({required List<Color> colors, List<double>? stops, required double minValue, required double maxValue})
const
HeatmapColorScale.blueToRed({required double minValue, required double maxValue})
Default blue to red color scale.
factory
HeatmapColorScale.viridis({required double minValue, required double maxValue})
Viridis color scale.
factory

Properties

colors List<Color>
final
hashCode int
The hash code for this object.
no setterinherited
maxValue double
final
minValue double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stops List<double>?
final

Methods

getColor(double value) Color
Get color for a value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited