HeatmapDataPoint class

Data point for heatmap.

Constructors

HeatmapDataPoint({required int row, required int column, required double value, Map<String, dynamic>? metadata})
const

Properties

column int
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited