HeatmapGrid class

Grid of heatmap cells with automatic sizing.

Inheritance

Constructors

HeatmapGrid({Key? key, required List<List<double>> values, required double minValue, required double maxValue, Color startColor = const Color(0xFF2166AC), Color endColor = const Color(0xFFB2182B), double cellRadius = 2, double cellPadding = 1, bool showValues = false, TextStyle? valueStyle, void onCellTap(int row, int column, double value)?})
const

Properties

cellPadding double
Cell padding.
final
cellRadius double
Cell corner radius.
final
endColor Color
End color for gradient.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue double
Maximum value for color scale.
final
minValue double
Minimum value for color scale.
final
onCellTap → void Function(int row, int column, double value)?
Callback when a cell is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValues bool
Whether to show values in cells.
final
startColor Color
Start color for gradient.
final
values List<List<double>>
2D list of values (rows x columns).
final
valueStyle TextStyle?
Value text style.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited