LabelAnchor enum

Anchor point for positioning the label relative to its coordinates.

Inheritance
Available extensions

Values

center → const LabelAnchor

Center of the label at the coordinates.

topLeft → const LabelAnchor

Top-left corner at the coordinates.

topCenter → const LabelAnchor

Top-center at the coordinates.

topRight → const LabelAnchor

Top-right corner at the coordinates.

middleLeft → const LabelAnchor

Middle-left at the coordinates.

middleRight → const LabelAnchor

Middle-right at the coordinates.

bottomLeft → const LabelAnchor

Bottom-left corner at the coordinates.

bottomCenter → const LabelAnchor

Bottom-center at the coordinates.

bottomRight → const LabelAnchor

Bottom-right corner at the coordinates.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LabelAnchor>
A constant List of the values in this enum, in order of their declaration.