LegendItem class

A standalone legend item widget with a symbol and label.

LegendItem can be used to build custom legend layouts or to display individual legend entries outside of a Legend widget.

Example usage:

LegendItem(
  label: 'Sales',
  color: Colors.blue,
  symbolShape: LegendSymbolShape.circle,
  symbolSize: 12,
)
Inheritance

Constructors

LegendItem({Key? key, required String label, required Color color, LegendSymbolShape symbolShape = LegendSymbolShape.circle, double symbolSize = 12, double symbolLabelSpacing = 4, TextStyle? labelStyle, VoidCallback? onTap, bool isSelected = true, double inactiveOpacity = 0.3})
Creates a legend item.
const

Properties

color → Color
The color for the symbol.
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveOpacity → double
Opacity when not selected (if part of a toggleable legend).
final
isSelected → bool
Whether the item is currently selected.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The label text.
final
labelStyle → TextStyle?
Text style for the label.
final
onTap → VoidCallback?
Callback when the item is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolLabelSpacing → double
Spacing between symbol and label.
final
symbolShape → LegendSymbolShape
The shape of the symbol.
final
symbolSize → double
The size of the symbol.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited