LegendLinearConfig class

Configuration for the linear legend.

Constructors

LegendLinearConfig({LegendLinearOrientation orientation = LegendLinearOrientation.horizontal, double length = 200, double thickness = 12, double borderRadius = 2, TextStyle? labelStyle, int labelCount = 5, double labelSpacing = 4})
Creates a linear legend configuration.
const

Properties

borderRadius double
Border radius for the gradient bar.
final
hashCode int
The hash code for this object.
no setterinherited
labelCount int
Number of tick labels to show.
final
labelSpacing double
Spacing between the gradient bar and labels.
final
labelStyle TextStyle?
Text style for labels.
final
length double
The length of the gradient bar.
final
orientation LegendLinearOrientation
The orientation of the gradient.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
The thickness of the gradient bar.
final

Methods

copyWith({LegendLinearOrientation? orientation, double? length, double? thickness, double? borderRadius, TextStyle? labelStyle, int? labelCount, double? labelSpacing}) LegendLinearConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited