LineAnnotationConfig class

Configuration for line annotations.

Inheritance

Constructors

LineAnnotationConfig({Color color = const Color(0xFF666666), double strokeWidth = 1, List<double>? dashPattern, AnnotationOrientation orientation = AnnotationOrientation.horizontal})
Creates a line annotation configuration.
const

Properties

color Color
The color of the annotation.
finalinherited
dashPattern List<double>?
The dash pattern for line annotations. If null, solid lines are drawn.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
orientation AnnotationOrientation
The orientation of the line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
The stroke width for line annotations.
finalinherited

Methods

copyWith({Color? color, double? strokeWidth, List<double>? dashPattern, AnnotationOrientation? orientation}) LineAnnotationConfig
Creates a copy with modified values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited