LinePath class

A widget that draws a line path through data points.

Inheritance

Constructors

LinePath({Key? key, required List<Point> points, Curve? curve, Color color = const Color(0xFF000000), double strokeWidth = 1.0, StrokeCap strokeCap = StrokeCap.butt, StrokeJoin strokeJoin = StrokeJoin.miter, List<double>? dashPattern, bool defined(Point)?})
Creates a line path widget.
const

Properties

color Color
The stroke color.
final
curve Curve?
Optional curve generator for smooth lines.
final
dashPattern List<double>?
Optional dash pattern dash, gap, dash, gap, ....
final
defined bool Function(Point)?
Whether the line is defined (drawn) for null/invalid points.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
points List<Point>
The data points to draw the line through.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeCap StrokeCap
The stroke cap style.
final
strokeJoin StrokeJoin
The stroke join style.
final
strokeWidth double
The stroke width.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited