LinearRegressionResult class

Result of a linear regression.

Constructors

LinearRegressionResult({required double slope, required double intercept, required double rSquared})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
intercept double
The y-intercept of the regression line.
final
rSquared double
The coefficient of determination (R-squared).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slope double
The slope of the regression line.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(double x) double
Predicts the y value for a given x.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited