LinkForce class

Force that maintains link distances.

Inheritance

Constructors

LinkForce({required List<NetworkLink> links, double distance = 30, double strength = 1, int iterations = 1})

Properties

distance double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iterations int
getter/setter pair
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
getter/setter pair

Methods

apply(ForceSimulation simulation) → void
Applies the force to the simulation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited