LoessResult class

Result of LOESS (locally weighted scatterplot smoothing).

Constructors

LoessResult({required List<double> x, required List<double> y})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x List<double>
The x values.
final
y List<double>
The smoothed y values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited