ManyBodyForce class

Repulsive force between all nodes (charge).

Inheritance

Constructors

ManyBodyForce({double strength = -30, double theta = 0.9, double distanceMin = 1, double distanceMax = double.infinity})

Properties

distanceMax double
getter/setter pair
distanceMin double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strength double
getter/setter pair
theta double
getter/setter pair

Methods

apply(ForceSimulation simulation) → void
Applies the force to the simulation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited