offset property
Offset
get
offset
Returns the offset for positioning content within the margin.
Implementation
Offset get offset => Offset(left, top);
Returns the offset for positioning content within the margin.
Offset get offset => Offset(left, top);