OHLCPoint class

OHLC (Open-High-Low-Close) data point.

Constructors

OHLCPoint({required DateTime timestamp, required double open, required double high, required double low, required double close, int? volume})
const

Properties

bodySize double
The body size (absolute difference between open and close).
no setter
close double
final
hashCode int
The hash code for this object.
no setterinherited
high double
final
isBullish bool
Whether this candle is bullish (close > open).
no setter
low double
final
open double
final
range double
The range (high - low).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
volume int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited