OrthographicProjection class
Orthographic projection (globe view). Shows the Earth as it appears from space.
- Implemented types
- Mixed-in types
Constructors
Properties
- center ↔ (double, double)
-
The center of the projection
longitude, latitude.getter/setter pairinherited - centerLat → double
-
The center latitude (for use in subclasses).
no setterinherited
- centerLon → double
-
The center longitude (for use in subclasses).
no setterinherited
- clipAngle → double
-
Returns the clip angle (90 degrees for orthographic).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotate ↔ (double, double, double)
-
The rotation angles
lambda, phi, gamma.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ double
-
The scale factor.
getter/setter pairinherited
- translate ↔ Point
-
The translation offset.
getter/setter pairinherited
Methods
-
applyTransform(
double x, double y) → Point -
Applies scale and translation to raw projected coordinates.
inherited
-
copy(
) → Projection -
Creates a copy of this projection.
override
-
invert(
double x, double y) → (double, double) -
Inverts screen coordinates to geographic
longitude, latitude.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
project(
double longitude, double latitude) → Point -
Projects a geographic coordinate
longitude, latitudeto screen coordinates.override -
removeTransform(
double x, double y) → (double, double) -
Removes scale and translation from screen coordinates.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited