Pattern class abstract

Base class for pattern fills.

Implementers

Constructors

Pattern({required double width, required double height, Color backgroundColor = const Color(0x00000000), Color foregroundColor = const Color(0xFF000000)})
Creates a pattern.
const

Properties

backgroundColor Color
The background color.
final
foregroundColor Color
The foreground/pattern color.
final
hashCode int
The hash code for this object.
no setterinherited
height double
The pattern height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The pattern width.
final

Methods

createShader(Rect bounds) Shader
Creates a shader that tiles this pattern.
drawPattern(Canvas canvas, Size size) → void
Draws the pattern once at origin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited