angle property
double
get
angle
Returns the angle of this point relative to the origin.
Implementation
double get angle => math.atan2(y, x);
Returns the angle of this point relative to the origin.
double get angle => math.atan2(y, x);