squaredMagnitude property
double
get
squaredMagnitude
Returns the squared magnitude of this point as a vector.
Implementation
double get squaredMagnitude => x * x + y * y;
Returns the squared magnitude of this point as a vector.
double get squaredMagnitude => x * x + y * y;