call method
Returns the position of the point for the given value.
Implementation
double call(T value) {
final index = _domain.indexOf(value);
if (index < 0) return double.nan;
return _pointPosition(index);
}
Returns the position of the point for the given value.
double call(T value) {
final index = _domain.indexOf(value);
if (index < 0) return double.nan;
return _pointPosition(index);
}