PolynomialRegressionResult class

Result of polynomial regression.

Constructors

PolynomialRegressionResult({required List<double> coefficients, required double rSquared})
const

Properties

coefficients List<double>
Coefficients a0, a1, a2, ... for y = a0 + a1x + a2x^2 + ...
final
degree int
The degree of the polynomial.
no setter
hashCode int
The hash code for this object.
no setterinherited
rSquared double
The coefficient of determination (R-squared).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(double x) double
Predicts the y value for a given x.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited