PositionedDraggable class

A widget that can be positioned by dragging.

Unlike DraggableWidget which reports drag state through callbacks, PositionedDraggable actually moves its child based on drag gestures.

Inheritance

Constructors

PositionedDraggable({Key? key, required Widget child, Offset initialPosition = Offset.zero, void onPositionChanged(Offset position)?, bool enabled = true, DragDirection direction = DragDirection.both, DragConstraints? constraints})
Creates a PositionedDraggable widget.
const

Properties

child Widget
The child widget.
final
constraints DragConstraints?
Constraints for the drag operation.
final
direction DragDirection
The direction of allowed drag movement.
final
enabled bool
Whether drag is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
initialPosition Offset
The initial position.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPositionChanged → void Function(Offset position)?
Called when the position changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PositionedDraggable>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited