PowerScale class

A power scale applies an exponential transform to the domain.

Implemented types

Constructors

PowerScale({List<double>? domain, List<double>? range, bool clamp = false, double exponent = 1})
Creates a power scale with the given parameters.

Properties

clamp bool
Whether output values are clamped to the range.
getter/setter pairoverride
domain List<double>
The input domain.
getter/setter pairoverride
exponent double
The exponent of the power transform.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
range List<double>
The output range.
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(double value) double
Maps a domain value to a range value.
override
copy() PowerScale
Creates a copy of this scale.
override
invert(double value) double
Maps a range value back to a domain value.
override
nice([int count = 10]) PowerScale
Returns nicely rounded domain values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tickFormat([int count = 10, String? specifier]) String Function(double)
Returns a tick format function.
override
ticks([int count = 10]) List<double>
Returns tick values for the scale.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited