Projection class abstract

Base class for geographic projections.

Implementers

Constructors

Projection()

Properties

center ↔ (double, double)
The center of the projection longitude, latitude.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
The scale factor.
getter/setter pair
translate Point
The translation offset.
getter/setter pair

Methods

copy() Projection
Creates a copy of this projection.
invert(double x, double y) → (double, double)
Inverts screen coordinates to geographic longitude, latitude.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
project(double longitude, double latitude) Point
Projects a geographic coordinate longitude, latitude to screen coordinates.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited