RadialGradientDef class

A radial gradient definition widget for chart styling.

Inheritance

Constructors

RadialGradientDef({Key? key, required String id, required List<GradientStop> stops, Alignment center = Alignment.center, double radius = 0.5, Alignment? focal, double focalRadius = 0.0, TileMode tileMode = TileMode.clamp, GradientTransform? transform, Widget? child})
Creates a radial gradient definition.
const

Properties

center Alignment
The center of the gradient.
final
child Widget?
Child widget to apply the gradient to.
final
focal Alignment?
The focal point of the gradient (defaults to center).
final
focalRadius double
The focal radius.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this gradient.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius double
The radius of the gradient (1.0 = corner to corner).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stops List<GradientStop>
The gradient stops and colors.
final
tileMode TileMode
How to tile the gradient beyond its bounds.
final
transform GradientTransform?
Optional transform matrix.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
createShader(Rect bounds) Shader
Creates a shader from this gradient for the given bounds.
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGradient() RadialGradient
Creates the Flutter RadialGradient from this definition.
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited