RectClip class

A rectangular clip widget.

Inheritance

Constructors

RectClip({Key? key, required Rect rect, required Widget child, Clip clipBehavior = Clip.antiAlias, double? cornerRadius, BorderRadius? borderRadius})
Creates a rectangular clip widget.
const
RectClip.fromLTRB(double left, double top, double right, double bottom, {Key? key, required Widget child, Clip clipBehavior = Clip.antiAlias, double? cornerRadius})
Creates a rectangular clip from LTRB values.
factory
RectClip.fromLTWH(double left, double top, double width, double height, {Key? key, required Widget child, Clip clipBehavior = Clip.antiAlias, double? cornerRadius})
Creates a rectangular clip from position and size.
factory

Properties

borderRadius BorderRadius?
Optional individual corner radii.
final
child Widget
The child widget to clip.
final
clipBehavior Clip
The clip behavior.
final
cornerRadius double?
Optional corner radius for rounded corners.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rect Rect
The clip rectangle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inset({Key? key, required Widget child, required EdgeInsets insets, Clip clipBehavior = Clip.antiAlias, double? cornerRadius}) Widget
Creates a rectangular clip with insets from the parent size.