ReferenceArea class

Reference area annotation for charts.

Inheritance

Constructors

ReferenceArea({Key? key, required Offset topLeft, required Offset bottomRight, Color color = Colors.blue, double opacity = 0.2, Color? borderColor, double borderWidth = 1, List<double>? borderDashPattern, double cornerRadius = 0, bool showLabel = false, String? label, TextStyle? labelStyle, ReferenceAreaLabelPosition labelPosition = ReferenceAreaLabelPosition.topLeft, Gradient? gradient, VoidCallback? onTap})
const
ReferenceArea.horizontalBand({required double yMin, required double yMax, required double xStart, required double xEnd, Color color = Colors.blue, double opacity = 0.2, Color? borderColor, double borderWidth = 1, String? label, TextStyle? labelStyle})
Creates a horizontal band area.
factory
ReferenceArea.verticalBand({required double xMin, required double xMax, required double yStart, required double yEnd, Color color = Colors.blue, double opacity = 0.2, Color? borderColor, double borderWidth = 1, String? label, TextStyle? labelStyle})
Creates a vertical band area.
factory

Properties

borderColor Color?
Border color.
final
borderDashPattern List<double>?
Border dash pattern (null for solid border).
final
borderWidth double
Border width.
final
bottomRight Offset
Bottom-right corner of the area.
final
color Color
Fill color.
final
cornerRadius double
Corner radius.
final
gradient Gradient?
Gradient fill (overrides color if provided).
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Label text.
final
labelPosition ReferenceAreaLabelPosition
Label position within the area.
final
labelStyle TextStyle?
Label style.
final
onTap VoidCallback?
Callback when area is tapped.
final
opacity double
Fill opacity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabel bool
Whether to show the label.
final
topLeft Offset
Top-left corner of the area.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited