ReferenceAreaConfig class

Configuration for a single reference area.

Constructors

ReferenceAreaConfig({required Offset topLeft, required Offset bottomRight, Color? color, double? opacity, Color? borderColor, double? borderWidth, String? label, TextStyle? labelStyle, ReferenceAreaLabelPosition labelPosition = ReferenceAreaLabelPosition.topLeft})
const

Properties

borderColor Color?
final
borderWidth double?
final
bottomRight Offset
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
labelPosition ReferenceAreaLabelPosition
final
labelStyle TextStyle?
final
opacity double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft Offset
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited