ReferenceLine class

Reference line annotation for charts.

Inheritance

Constructors

ReferenceLine({Key? key, required Offset start, required Offset end, Color color = Colors.grey, double width = 1, List<double>? dashPattern, bool showMarkers = false, double markerRadius = 4, Color? markerColor, bool showLabel = false, String? label, TextStyle? labelStyle, Offset labelOffset = const Offset(0, -10), VoidCallback? onTap})
const
ReferenceLine.horizontal({required double y, required double startX, required double endX, Color color = Colors.grey, double width = 1, List<double>? dashPattern, bool showLabel = false, String? label, TextStyle? labelStyle})
Creates a horizontal reference line.
factory
ReferenceLine.vertical({required double x, required double startY, required double endY, Color color = Colors.grey, double width = 1, List<double>? dashPattern, bool showLabel = false, String? label, TextStyle? labelStyle})
Creates a vertical reference line.
factory

Properties

color Color
Line color.
final
dashPattern List<double>?
Line dash pattern (null for solid line).
final
end Offset
End point of the line.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Label text.
final
labelOffset Offset
Label offset from the line.
final
labelStyle TextStyle?
Label style.
final
markerColor Color?
Marker fill color.
final
markerRadius double
Marker radius.
final
onTap VoidCallback?
Callback when line is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabel bool
Whether to show the label.
final
showMarkers bool
Whether to show markers at endpoints.
final
start Offset
Start point of the line.
final
width double
Line width.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited