ResponsiveBuilder class

A widget that builds different layouts based on screen size.

Inheritance

Constructors

ResponsiveBuilder({Key? key, Widget extraSmall(BuildContext context, BoxConstraints constraints)?, Widget small(BuildContext context, BoxConstraints constraints)?, Widget medium(BuildContext context, BoxConstraints constraints)?, Widget large(BuildContext context, BoxConstraints constraints)?, required Widget defaultBuilder(BuildContext context, BoxConstraints constraints), Breakpoints breakpoints = const Breakpoints()})
Creates a ResponsiveBuilder widget.
const

Properties

breakpoints → Breakpoints
The breakpoints to use.
final
defaultBuilder Widget Function(BuildContext context, BoxConstraints constraints)
The default builder used when a specific size builder is not provided.
final
extraSmall Widget Function(BuildContext context, BoxConstraints constraints)?
The builder for extra small screens.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
large Widget Function(BuildContext context, BoxConstraints constraints)?
The builder for large screens.
final
medium Widget Function(BuildContext context, BoxConstraints constraints)?
The builder for medium screens.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small Widget Function(BuildContext context, BoxConstraints constraints)?
The builder for small screens.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited