ResponsiveContainer class

A widget that provides responsive behavior based on available space.

ResponsiveContainer wraps its child and provides size information through a builder function, allowing for responsive chart layouts.

Inheritance

Constructors

ResponsiveContainer({Key? key, required Widget builder(BuildContext context, BoxConstraints constraints, ScreenSize screenSize), Breakpoints breakpoints = const Breakpoints(), double? minWidth, double? minHeight, double? maxWidth, double? maxHeight, double? aspectRatio})
Creates a ResponsiveContainer widget.
const

Properties

aspectRatio double?
The aspect ratio to maintain.
final
breakpoints → Breakpoints
The breakpoints to use for determining screen size.
final
builder Widget Function(BuildContext context, BoxConstraints constraints, ScreenSize screenSize)
The builder function that creates the child widget.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight double?
The maximum height of the container.
final
maxWidth double?
The maximum width of the container.
final
minHeight double?
The minimum height of the container.
final
minWidth double?
The minimum width of the container.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited