ScatterSeries class

Scatter series for XY charts.

Inheritance

Constructors

ScatterSeries({Key? key, required List<XYDataPoint> data, Color color = Colors.blue, Color? borderColor, double borderWidth = 1, double radius = 5, MarkerShape shape = MarkerShape.circle, double opacity = 1.0, double radiusAccessor(XYDataPoint point)?, Color colorAccessor(XYDataPoint point)?, void onPointTap(XYDataPoint point, int index)?})
const

Properties

borderColor Color?
Marker border color.
final
borderWidth double
Marker border width.
final
color Color
Marker fill color.
final
colorAccessor Color Function(XYDataPoint point)?
Function to compute color from data point.
final
data List<XYDataPoint>
Data points for the scatter plot.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPointTap → void Function(XYDataPoint point, int index)?
Callback when a point is tapped.
final
opacity double
Opacity (0-1).
final
radius double
Marker radius.
final
radiusAccessor double Function(XYDataPoint point)?
Function to compute radius from data point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape MarkerShape
Marker shape.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited