SequentialLogScale<R> class

Sequential scale with log transform.

Constructors

SequentialLogScale({List<double>? domain, required Interpolator<R> interpolator, bool clamp = false, double base = 10})

Properties

base double
getter/setter pair
clamp bool
getter/setter pair
domain List<double>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interpolator Interpolator<R>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(double value) → R
copy() SequentialLogScale<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited