SequentialScale<R> class

A sequential scale maps a continuous domain to a color scheme using an interpolator.

Constructors

SequentialScale({List<double>? domain, required Interpolator<R> interpolator, bool clamp = false})
Creates a sequential scale with the given parameters.

Properties

clamp bool
Whether to clamp output values.
getter/setter pair
domain List<double>
The input domain.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interpolator Interpolator<R>
The interpolator function.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(double value) → R
Maps a domain value to a range value.
copy() SequentialScale<R>
Creates a copy of this scale.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited