StackSeries<T> class
A stacked series containing points for one key.
Constructors
-
StackSeries({required String key, required List<
StackPoint< points})T> > - Creates a stack series.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The series key.
final
-
points
→ List<
StackPoint< T> > -
The stacked points.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited