StarGlyph class

A star glyph marker.

Inheritance

Constructors

StarGlyph({Key? key, required double x, required double y, double size = 8, Color color = const Color(0xFF000000), Color? strokeColor, double strokeWidth = 1.0, double rotation = 0, double opacity = 1.0, int points = 5, double innerRadiusFactor = 0.5})
Creates a star glyph.
const

Properties

color Color
The fill color.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
innerRadiusFactor double
Inner radius as a fraction of outer radius.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity double
Optional opacity (0.0 - 1.0).
finalinherited
points int
Number of points on the star.
final
rotation double
Optional rotation angle in radians.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the glyph.
finalinherited
strokeColor Color?
Optional stroke color.
finalinherited
strokeWidth double
The stroke width.
finalinherited
x double
The x coordinate of the glyph center.
finalinherited
y double
The y coordinate of the glyph center.
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
createPath() Path
Returns the path for this glyph shape centered at origin.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited