SweepGradientDef class

A sweep (angular) gradient definition widget.

Inheritance

Constructors

SweepGradientDef({Key? key, required String id, required List<GradientStop> stops, Alignment center = Alignment.center, double startAngle = 0.0, double endAngle = 6.283185307179586, TileMode tileMode = TileMode.clamp, GradientTransform? transform, Widget? child})
Creates a sweep gradient definition.
const

Properties

center Alignment
The center of the gradient.
final
child Widget?
Child widget to apply the gradient to.
final
endAngle double
The end angle in radians.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this gradient.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAngle double
The start angle in radians.
final
stops List<GradientStop>
The gradient stops and colors.
final
tileMode TileMode
How to tile the gradient beyond its bounds.
final
transform GradientTransform?
Optional transform matrix.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
createShader(Rect bounds) Shader
Creates a shader from this gradient for the given bounds.
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toGradient() SweepGradient
Creates the Flutter SweepGradient from this definition.
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited