SymlogScale class

A symmetric log scale that handles both positive and negative values. Uses the bi-symmetric log transform: sign(x) * log(1 + |x / constant|)

Implemented types

Constructors

SymlogScale({List<double>? domain, List<double>? range, bool clamp = false, double constant = 1})
Creates a symlog scale with the given parameters.

Properties

clamp bool
Whether output values are clamped to the range.
getter/setter pairoverride
constant double
The constant used in the symlog transform.
getter/setter pair
domain List<double>
The input domain.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
range List<double>
The output range.
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(double value) double
Maps a domain value to a range value.
override
copy() SymlogScale
Creates a copy of this scale.
override
invert(double value) double
Maps a range value back to a domain value.
override
nice([int count = 10]) SymlogScale
Returns nicely rounded domain values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tickFormat([int count = 10, String? specifier]) String Function(double)
Returns a tick format function.
override
ticks([int count = 10]) List<double>
Returns tick values for the scale.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited