TextLabel class

A single text label definition.

Constructors

TextLabel({required String text, required double x, required double y, TextStyle? style, TextAnchor anchor = TextAnchor.start, double rotation = 0})
Creates a text label.
const

Properties

anchor TextAnchor
Horizontal anchor point.
final
hashCode int
The hash code for this object.
no setterinherited
rotation double
Rotation angle in radians.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
Optional text style override.
final
text String
The text content.
final
x double
The x position.
final
y double
The y position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited