TickConfig class

Configuration for axis tick marks.

Constructors

TickConfig({double tickLength = 6, double tickPadding = 3, double tickStrokeWidth = 1, Color tickColor = const Color(0xFF000000)})
Creates a tick configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tickColor Color
The color of tick marks.
final
tickLength double
The length of tick marks in pixels.
final
tickPadding double
The padding between tick marks and labels.
final
tickStrokeWidth double
The stroke width of tick marks.
final

Methods

copyWith({double? tickLength, double? tickPadding, double? tickStrokeWidth, Color? tickColor}) TickConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited