TooltipController class

A controller for managing tooltip visibility and position.

Inheritance

Constructors

TooltipController()

Properties

data → dynamic
The data associated with the current tooltip.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isVisible bool
Whether the tooltip is currently visible.
no setter
position Offset?
The current position of the tooltip target.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clears all tooltip data.
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
hide() → void
Hides the tooltip.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
show(Offset position, dynamic data) → void
Shows the tooltip at the given position with the given data.
toString() String
A string representation of this object.
inherited
updatePosition(Offset position) → void
Updates the tooltip position without changing visibility or data.

Operators

operator ==(Object other) bool
The equality operator.
inherited