show method
Shows the tooltip at the given position with the given data.
Implementation
void show(Offset position, dynamic data) {
_position = position;
_data = data;
_isVisible = true;
notifyListeners();
}
Shows the tooltip at the given position with the given data.
void show(Offset position, dynamic data) {
_position = position;
_data = data;
_isVisible = true;
notifyListeners();
}