TooltipItem class

A single tooltip item with optional color indicator.

Constructors

TooltipItem({required String label, required String value, Color? color, Map<String, dynamic>? metadata})
Creates a TooltipItem.
const

Properties

color Color?
The color associated with this item.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The label for this item.
final
metadata Map<String, dynamic>?
Additional metadata.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value for this item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited