TooltipOverlay class

A widget that manages a tooltip overlay for a chart.

This widget provides a convenient way to show/hide tooltips based on user interactions.

Inheritance

Constructors

TooltipOverlay({Key? key, required Widget child, required TooltipController controller, required Widget tooltipBuilder(BuildContext context, dynamic data), TooltipPosition position = TooltipPosition.top, Offset offset = const Offset(0, 8), Color? backgroundColor, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(4)), EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8)})
Creates a TooltipOverlay widget.
const

Properties

backgroundColor Color?
The background color of the tooltip.
final
borderRadius BorderRadius
The border radius of the tooltip.
final
child Widget
The child widget (usually a chart).
final
controller TooltipController
The controller for managing tooltip state.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset Offset
The offset from the target position.
final
padding EdgeInsets
The padding inside the tooltip.
final
position TooltipPosition
The preferred position of the tooltip.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltipBuilder Widget Function(BuildContext context, dynamic data)
The builder function for creating tooltip content.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TooltipOverlay>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited