XYChart class

XY Chart widget that combines axes, grid, and series.

Inheritance

Constructors

XYChart({Key? key, required List<Widget> children, LinearScale? xScale, LinearScale? yScale, ChartMargin margin = const ChartMargin(), bool showXAxis = true, bool showYAxis = true, bool showGrid = true, String? xAxisLabel, String? yAxisLabel, Color? backgroundColor, Color gridColor = const Color(0xFFE0E0E0), Color axisColor = const Color(0xFF757575), void onPointTap(XYDataPoint point)?})
const

Properties

axisColor Color
Axis line color.
final
backgroundColor Color?
Background color.
final
children List<Widget>
The child series widgets to render.
final
gridColor Color
Grid line color.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin ChartMargin
Chart margins.
final
onPointTap → void Function(XYDataPoint point)?
Callback when a data point is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGrid bool
Whether to show grid lines.
final
showXAxis bool
Whether to show the X axis.
final
showYAxis bool
Whether to show the Y axis.
final
xAxisLabel String?
X-axis label.
final
xScale LinearScale?
X-axis scale configuration.
final
yAxisLabel String?
Y-axis label.
final
yScale LinearScale?
Y-axis scale configuration.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<XYChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited