interpolateRound function
Creates a round interpolator that rounds to the nearest integer.
Implementation
Interpolator<num> interpolateRound(num a, num b) {
return (double t) => (a + (b - a) * t).round();
}
Creates a round interpolator that rounds to the nearest integer.
Interpolator<num> interpolateRound(num a, num b) {
return (double t) => (a + (b - a) * t).round();
}