AreaAnnotationConfig class
Configuration for area annotations.
Constructors
- AreaAnnotationConfig({Color fillColor = const Color(0xFF666666), double fillOpacity = 0.2, bool showBorder = false, Color borderColor = const Color(0xFF666666), double borderWidth = 1, AnnotationOrientation orientation = AnnotationOrientation.horizontal})
-
Creates an area annotation configuration.
const
Properties
- borderColor → Color
-
The border color.
final
- borderWidth → double
-
The border stroke width.
final
- fillColor → Color
-
The fill color of the area.
final
- fillOpacity → double
-
The opacity of the fill (0.0 to 1.0).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orientation → AnnotationOrientation
-
The orientation of the area.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBorder → bool
-
Whether to show a border.
final
Methods
-
copyWith(
{Color? fillColor, double? fillOpacity, bool? showBorder, Color? borderColor, double? borderWidth, AnnotationOrientation? orientation}) → AreaAnnotationConfig - Creates a copy with modified values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited