AreaSeries class
Area series for XY charts.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AreaSeries
Constructors
Properties
- baseline → double
-
Baseline value (y-axis value where area starts).
final
- color → Color
-
Fill color.
final
-
data
→ List<
XYDataPoint> -
Data points for the area.
final
- gradient → Gradient?
-
Gradient for area fill.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineColor → Color?
-
Line color (defaults to area color).
final
- lineWidth → double
-
Line stroke width.
final
- opacity → double
-
Fill opacity (0-1).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLine → bool
-
Whether to show the line on top of the area.
final
- smooth → bool
-
Whether to draw a smooth curve.
final
- tension → double
-
Curve tension (0-1) for smooth curves.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited