Bin<T> class

Represents a histogram bin.

Constructors

Bin({required num x0, required num x1, required List<T> values})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
The number of values in this bin.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<T>
The values in this bin.
final
x0 num
The lower bound (inclusive) of this bin.
final
x1 num
The upper bound (exclusive) of this bin.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited