Bisector<T, V extends Comparable<Object> > class
Creates a bisector with custom comparison.
Constructors
- Bisector(V accessor(T))
-
const
Properties
- accessor → V Function(T)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
center(
List< T> list, V value, {int lo = 0, int? hi}) → int - Finds the center (closest element).
-
left(
List< T> list, V value, {int lo = 0, int? hi}) → int - Finds the leftmost insertion point.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
right(
List< T> list, V value, {int lo = 0, int? hi}) → int - Finds the rightmost insertion point.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited