BrushStateMixin<T extends Brush> mixin
A mixin that provides common brush state management.
- Superclass constraints
- State<
T>
- State<
Properties
- brushState ↔ BrushState
-
The current brush state.
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- extent ↔ BrushExtent?
-
The current brush extent.
getter/setter pair
- gestureStartExtent ↔ BrushExtent?
-
The extent at the start of the current gesture.
getter/setter pair
- gestureStartPosition ↔ Offset?
-
The starting position of the current gesture.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → T
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
clearBrush(
) → void - Clears the brush selection.
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
endBrush(
) → void - Ends the brush selection.
-
endMove(
) → void - Ends moving the brush selection.
-
endResize(
) → void - Ends resizing the brush selection.
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
startBrush(
double position) → void - Starts a new brush selection.
-
startMove(
Offset position) → void - Starts moving the brush selection.
-
startResize(
bool isStart) → void - Starts resizing the brush selection.
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
updateBrush(
double position) → void - Updates the brush selection.
-
updateMove(
double delta, double minBound, double maxBound) → void - Updates the brush position during a move.
-
updateResize(
double position, double minBound, double maxBound) → void - Updates the brush during a resize.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited