ChartMargin class

Configuration for chart margins.

Constructors

ChartMargin({double top = 20, double right = 20, double bottom = 40, double left = 50})
const
ChartMargin.all(double value)
const

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited