CheckerPattern class

A checkerboard pattern.

Inheritance

Constructors

CheckerPattern({double squareSize = 10, Color backgroundColor = const Color(0x00000000), Color foregroundColor = const Color(0xFF000000), Color secondaryColor = const Color(0xFFFFFFFF)})
Creates a checker pattern.
const

Properties

backgroundColor Color
The background color.
finalinherited
foregroundColor Color
The foreground/pattern color.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double
The pattern height.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
The secondary color (for alternating squares).
final
squareSize double
The size of each square.
final
width double
The pattern width.
finalinherited

Methods

createShader(Rect bounds) Shader
Creates a shader that tiles this pattern.
inherited
drawPattern(Canvas canvas, Size size) → void
Draws the pattern once at origin.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited