CollideForce class
Force that pushes nodes away from each other for collision detection.
Constructors
- CollideForce({double radius = 10, double strength = 1, int iterations = 1})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations ↔ int
-
getter/setter pair
- radius ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strength ↔ double
-
getter/setter pair
Methods
-
apply(
ForceSimulation simulation) → void -
Applies the force to the simulation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited