ContinuousScale<D extends num, R> class
abstract
Base class for continuous scales that map a continuous domain to a range.
- Implementers
Constructors
Properties
- clamp ↔ bool
-
Whether output values are clamped to the range.
getter/setter pair
-
domain
↔ List<
D> -
The input domain.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
range
↔ List<
R> -
The output range.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
D value) → R - Maps a domain value to a range value.
-
copy(
) → ContinuousScale< D, R> - Creates a copy of this scale.
-
invert(
R value) → D - Maps a range value back to a domain value.
-
nice(
[int count]) → ContinuousScale< D, R> - Returns nicely rounded domain values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tickFormat(
[int count, String? specifier]) → String Function(D) - Returns a tick format function.
-
ticks(
[int count]) → List< D> - Returns tick values for the scale.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited