CurveContext class
Context for building paths from curve data.
Constructors
Properties
Methods
-
bezierCurveTo(
double cp1x, double cp1y, double cp2x, double cp2y, double x, double y) → void - Draws a cubic bezier curve to the given point.
-
closePath(
) → void - Closes the path.
-
lineTo(
double x, double y) → void - Draws a line to the given point.
-
moveTo(
double x, double y) → void - Moves to the given point.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
quadraticCurveTo(
double cpx, double cpy, double x, double y) → void - Draws a quadratic bezier curve to the given point.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited