DragController class

A controller for managing drag state externally.

Inheritance

Constructors

DragController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDragging bool
Whether a drag is currently active.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state DragState
The current drag state.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
cancel() → void
Cancels the drag operation.
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
end() → void
Ends the drag operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
start(Offset position) → void
Starts a drag operation.
toString() String
A string representation of this object.
inherited
update(Offset position, Offset delta) → void
Updates the drag position.

Operators

operator ==(Object other) bool
The equality operator.
inherited