ExponentialRegressionResult class
Result of an exponential regression.
Constructors
- ExponentialRegressionResult({required double a, required double b, required double rSquared})
-
const
Properties
- a → double
-
The coefficient 'a' in y = a * e^(b*x).
final
- b → double
-
The exponent coefficient 'b' in y = a * e^(b*x).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rSquared → double
-
The coefficient of determination (R-squared).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
predict(
double x) → double - Predicts the y value for a given x.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited