GeoJsonPoint class
A GeoJSON Point geometry.
- Implemented types
Constructors
-
GeoJsonPoint(List<
double> coordinates) -
GeoJsonPoint.fromJson(Map<
String, dynamic> json) -
factory
Properties
- altitude → double?
-
Altitude in meters (optional).
no setter
-
coordinates
→ List<
double> -
The coordinates
longitude, latitude, altitude?.final - hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Latitude in degrees.
no setter
- longitude → double
-
Longitude in degrees.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of this geometry.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to a GeoJSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited