GeoPath class
Generates path data from GeoJSON geometries using a projection.
Constructors
- GeoPath(Projection projection)
- Creates a GeoPath with the given projection.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projection ↔ Projection
-
The projection to use.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
area(
dynamic geoJson) → double - Calculates the area of a polygon geometry.
-
bounds(
dynamic geoJson) → (Point, Point)? - Calculates the bounding box of a geometry.
-
centroid(
dynamic geoJson) → Point? - Calculates the centroid of a geometry.
-
generate(
dynamic geoJson) → List< List< Point> > - Generates a list of paths (list of points) from a GeoJSON object.
-
measure(
dynamic geoJson) → double - Measures the length of a line geometry.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited