GradientPresets class
Common gradient presets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
bluePurple
→ const List<
GradientStop> - Blue to purple gradient.
-
gray
→ const List<
GradientStop> - Gray gradient.
-
greenTeal
→ const List<
GradientStop> - Green to teal gradient.
-
heatmap
→ const List<
GradientStop> - Heat map gradient (blue -> green -> yellow -> red).
-
orangeRed
→ const List<
GradientStop> - Orange to red gradient.