Graticule class
Generates graticule line data for a given projection.
Constructors
- Graticule(Projection projection, [GraticuleConfig config = const GraticuleConfig()])
- Creates a Graticule generator.
Properties
- config → GraticuleConfig
-
The graticule configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projection → Projection
-
The projection to use.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
latitudeLines(
) → List< List< Point> > - Generates latitude lines as lists of points.
-
lines(
) → List< List< Point> > - Generates all graticule lines.
-
longitudeLines(
) → List< List< Point> > - Generates longitude lines as lists of points.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited