GraticuleConfig class

Configuration for graticule lines.

Constructors

GraticuleConfig({double latitudeStep = 10.0, double longitudeStep = 10.0, double minLatitude = -90.0, double maxLatitude = 90.0, double minLongitude = -180.0, double maxLongitude = 180.0, int precision = 100})
Creates a graticule configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
latitudeStep double
The step in degrees for latitude lines.
final
longitudeStep double
The step in degrees for longitude lines.
final
maxLatitude double
The maximum latitude to render.
final
maxLongitude double
The maximum longitude to render.
final
minLatitude double
The minimum latitude to render.
final
minLongitude double
The minimum longitude to render.
final
precision int
The precision of each line (number of points).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

coarse → const GraticuleConfig
Creates a configuration with coarser grid lines.
defaultConfig → const GraticuleConfig
Default graticule configuration with 10 degree steps.
fine → const GraticuleConfig
Creates a configuration with finer grid lines.