GridConfig class
Configuration for grid lines.
Constructors
-
GridConfig({double strokeWidth = 1, Color color = const Color(0xFFE0E0E0), List<
double> ? dashPattern}) -
Creates a grid configuration.
const
Properties
- color → Color
-
The color of grid lines.
final
-
dashPattern
→ List<
double> ? -
The dash pattern for grid lines.
If null, solid lines are drawn.
Example:
5, 3means 5 pixels on, 3 pixels off.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
The stroke width of grid lines.
final
Methods
-
copyWith(
{double? strokeWidth, Color? color, List< double> ? dashPattern}) → GridConfig - Creates a copy with modified values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited