GroupedBarSeries class
Grouped bar series for multiple data sets.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GroupedBarSeries
Constructors
-
GroupedBarSeries({Key? key, required List<
List< dataSeries, required List<XYDataPoint> >Color> colors, double barWidth = 0.8, double groupGap = 0.1, double cornerRadius = 0}) -
const
Properties
- barWidth → double
-
Bar width as a fraction of available space (0-1).
final
-
colors
→ List<
Color> -
Colors for each series.
final
- cornerRadius → double
-
Corner radius for rounded bars.
final
-
dataSeries
→ List<
List< XYDataPoint> > -
List of data series, each with its own color.
final
- groupGap → double
-
Gap between bars in a group as a fraction (0-1).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited