LabelAnnotationConfig class

Configuration for label annotations.

Constructors

LabelAnnotationConfig({Color? backgroundColor, double backgroundOpacity = 0.8, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 2), double borderRadius = 2, bool showBorder = false, Color borderColor = const Color(0xFF666666), double borderWidth = 1, double rotation = 0})
Creates a label annotation configuration.
const

Properties

backgroundColor Color?
The background color of the label.
final
backgroundOpacity double
The background opacity.
final
borderColor Color
The border color.
final
borderRadius double
Border radius for the background.
final
borderWidth double
The border width.
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
Padding around the text.
final
rotation double
Rotation angle in degrees.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBorder bool
Whether to show a border.
final

Methods

copyWith({Color? backgroundColor, double? backgroundOpacity, EdgeInsets? padding, double? borderRadius, bool? showBorder, Color? borderColor, double? borderWidth, double? rotation}) LabelAnnotationConfig
Creates a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited