LegendConfig class
Configuration for legend appearance.
Constructors
- LegendConfig({LegendDirection direction = LegendDirection.horizontal, double itemSpacing = 16, double symbolSize = 12, double symbolLabelSpacing = 4, TextStyle? labelStyle, LegendSymbolShape symbolShape = LegendSymbolShape.circle})
-
Creates a legend configuration.
const
Properties
- direction → LegendDirection
-
The direction of the legend layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemSpacing → double
-
Spacing between legend items.
final
- labelStyle → TextStyle?
-
Text style for labels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbolLabelSpacing → double
-
Spacing between symbol and label.
final
- symbolShape → LegendSymbolShape
-
Shape of the legend symbols.
final
- symbolSize → double
-
Size of the symbol.
final
Methods
-
copyWith(
{LegendDirection? direction, double? itemSpacing, double? symbolSize, double? symbolLabelSpacing, TextStyle? labelStyle, LegendSymbolShape? symbolShape}) → LegendConfig - Creates a copy with modified values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited