LegendEntry class

Data for a legend entry.

Constructors

LegendEntry({required String label, required Color color, LegendSymbolShape? shape})
Creates a legend entry.
const

Properties

color Color
The color for this entry.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The label text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape LegendSymbolShape?
Optional custom symbol shape.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited