LegendLinear class
A legend for continuous/linear data showing a color gradient.
LegendLinear displays a gradient bar with tick labels to show the mapping between numeric values and colors in a continuous color scale.
Example usage:
LegendLinear(
scale: scaleSequential(
domain: [0, 100],
interpolator: interpolateBlues,
),
config: LegendLinearConfig(
length: 200,
labelCount: 5,
),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LegendLinear
Constructors
-
LegendLinear({Key? key, required dynamic scale, LegendLinearConfig config = const LegendLinearConfig(), List<
double> ? tickValues, String tickFormat(double)?, String? title, TextStyle? titleStyle}) -
Creates a linear legend.
const
Properties
- config → LegendLinearConfig
-
Configuration for the legend.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → dynamic
-
The continuous color scale to visualize.
final
- tickFormat → String Function(double)?
-
Custom tick format function.
final
-
tickValues
→ List<
double> ? -
Custom tick values for labels.
final
- title → String?
-
Optional title for the legend.
final
- titleStyle → TextStyle?
-
Text style for the title.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited