LegendOrdinal<T> class
A legend for categorical/ordinal data.
LegendOrdinal works with ordinal scales to display a legend that maps discrete domain values to colors or other visual properties.
Example usage:
LegendOrdinal(
scale: scaleOrdinal(
domain: ['A', 'B', 'C'],
range: [Colors.blue, Colors.red, Colors.green],
),
config: LegendConfig(direction: LegendDirection.horizontal),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LegendOrdinal
Constructors
-
LegendOrdinal({Key? key, required dynamic scale, Map<
T, String> ? labels, LegendConfig config = const LegendConfig(), void onTap(T value, int index)?, Set<T> ? selectedValues, double inactiveOpacity = 0.3}) -
Creates an ordinal legend.
const
Properties
- config → LegendConfig
-
Configuration for the legend.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveOpacity → double
-
Opacity for unselected items.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
labels
→ Map<
T, String> ? -
Optional custom labels for domain values.
final
- onTap → void Function(T value, int index)?
-
Callback when an entry is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → dynamic
-
The ordinal scale to use.
final
-
selectedValues
→ Set<
T> ? -
Set of selected values (for toggleable legends).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited