LinkWidget class
Widget for rendering a link between two nodes.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LinkWidget
Constructors
- LinkWidget({Key? key, required NetworkLink link, required NetworkNode sourceNode, required NetworkNode targetNode, Color color = Colors.grey, double width = 1, bool showLabel = false, TextStyle? labelStyle, LinkStyle style = LinkStyle.straight, double arrowSize = 8, bool highlighted = false, Color? highlightColor, VoidCallback? onTap})
-
const
Properties
- arrowSize → double
-
Arrow size for directed links.
final
- color → Color
-
Link color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
Highlight color.
final
- highlighted → bool
-
Whether the link is highlighted.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
Label text style.
final
- link → NetworkLink
-
The link data.
final
- onTap → VoidCallback?
-
Callback when link is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabel → bool
-
Whether to show the label.
final
- sourceNode → NetworkNode
-
Source node.
final
- style → LinkStyle
-
Link style.
final
- targetNode → NetworkNode
-
Target node.
final
- width → double
-
Link width.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited