MockData class
Mock data generator for various chart types.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- random → RandomGenerator
-
Access to the random generator.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeSeries → TimeSeriesGenerator
-
Access to the time series generator.
no setter
Methods
-
barData(
{int bars = 10, double minValue = 10, double maxValue = 100, List< String> ? categories}) → List<Map< String, dynamic> > - Generates bar chart data.
-
boxPlotData(
{int groups = 5, List< String> ? groupNames, int samplesPerGroup = 100}) → List<Map< String, dynamic> > - Generates box plot data.
-
calendarHeatmapData(
{required DateTime start, required DateTime end, double minValue = 0, double maxValue = 10, double emptyProbability = 0.2}) → Map< DateTime, double> - Generates calendar heatmap data.
-
correlationMatrix(
{int size = 10}) → List< List< double> > - Generates correlated heatmap data (like a correlation matrix).
-
geoPoints(
{int count = 50, double latMin = -90, double latMax = 90, double lonMin = -180, double lonMax = 180}) → List< Map< String, double> > - Generates random geographic points.
-
geoPointsClustered(
{int clusterCount = 5, int pointsPerCluster = 20, double clusterRadius = 5}) → List< Map< String, double> > - Generates clustered geographic points.
-
groupedBarData(
{int groups = 5, List< String> ? groupNames, List<String> ? seriesNames, int seriesCount = 3, double minValue = 10, double maxValue = 100}) → List<Map< String, dynamic> > - Generates grouped bar chart data.
-
heatmapData(
{int rows = 10, int columns = 10, double minValue = 0, double maxValue = 100}) → List< List< double> > - Generates heatmap data.
-
histogramData(
{int sampleCount = 1000, int binCount = 20, double mean = 50, double stdDev = 15}) → Map< String, dynamic> - Generates histogram data.
-
lineData(
{int points = 20, double startValue = 50, double volatility = 5, String xKey = 'x', String yKey = 'y'}) → List< Map< String, dynamic> > - Generates line chart data.
-
networkData(
{int nodeCount = 20, double linkProbability = 0.1, int? groupCount}) → Map< String, dynamic> - Generates network graph data.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pieData(
{int slices = 5, List< String> ? labels, bool sorted = true}) → List<Map< String, dynamic> > - Generates pie/donut chart data.
-
scatterData(
{int count = 50, double xMin = 0, double xMax = 100, double yMin = 0, double yMax = 100, double? correlation}) → List< Map< String, double> > - Generates scatter plot data points.
-
stackedData(
{int categories = 10, List< String> ? categoryNames, List<String> ? seriesNames, int seriesCount = 4, double minValue = 10, double maxValue = 50}) → List<Map< String, dynamic> > - Generates stacked data.
-
sunburstData(
{int depth = 3, int minChildren = 2, int maxChildren = 4}) → Map< String, dynamic> - Generates sunburst data.
-
toString(
) → String -
A string representation of this object.
inherited
-
treeData(
{int depth = 3, int minChildren = 1, int maxChildren = 4}) → Map< String, dynamic> - Generates tree structure data.
-
treemapData(
{int depth = 2, int minChildren = 2, int maxChildren = 5, double minValue = 10, double maxValue = 100, String name = 'Root'}) → Map< String, dynamic> - Generates treemap data.
-
violinData(
{int groups = 4, List< String> ? groupNames, int samplesPerGroup = 200}) → List<Map< String, dynamic> > - Generates violin plot data.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited