NetworkLink class
Data class representing a link/edge in a network graph.
Constructors
Properties
- color ↔ Color?
-
Link color.
getter/setter pair
- directed → bool
-
Whether the link is directed.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
Link label.
final
-
metadata
→ Map<
String, dynamic> ? -
Custom metadata.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
Source node ID.
final
- target → String
-
Target node ID.
final
- weight → double
-
Link weight/strength.
final
- width ↔ double
-
Link width.
getter/setter pair
Methods
-
copyWith(
{String? source, String? target, double? weight, String? label, Color? color, double? width, bool? directed, Map< String, dynamic> ? metadata}) → NetworkLink - Creates a copy of this link.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override