NetworkNode class
Data class representing a node in a network graph.
Constructors
Properties
- color ↔ Color?
-
Node color.
getter/setter pair
- fixed ↔ bool
-
Whether the node position is fixed.
getter/setter pair
- group → String?
-
Node group/category for styling.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier for the node.
final
- label → String?
-
Display label for the node.
final
-
metadata
→ Map<
String, dynamic> ? -
Custom metadata.
final
- radius ↔ double
-
Node radius.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vx ↔ double
-
Velocity x component (for force simulation).
getter/setter pair
- vy ↔ double
-
Velocity y component (for force simulation).
getter/setter pair
- x ↔ double
-
Current x position.
getter/setter pair
- y ↔ double
-
Current y position.
getter/setter pair
Methods
-
copyWith(
{String? id, String? label, String? group, double? x, double? y, double? vx, double? vy, bool? fixed, double? radius, Color? color, Map< String, dynamic> ? metadata}) → NetworkNode - Creates a copy of this node.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override