NodeWidget class
Widget for rendering a single node.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NodeWidget
Constructors
- NodeWidget({Key? key, required NetworkNode node, Color color = Colors.blue, Color? borderColor, double borderWidth = 2, bool showLabel = true, TextStyle? labelStyle, NodeShape shape = NodeShape.circle, bool selected = false, Color? selectionColor, VoidCallback? onTap, void onDragStart(DragStartDetails)?, void onDragUpdate(DragUpdateDetails)?, void onDragEnd(DragEndDetails)?})
-
const
Properties
- borderColor → Color?
-
Node border color.
final
- borderWidth → double
-
Node border width.
final
- color → Color
-
Node fill color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
Label text style.
final
- node → NetworkNode
-
The node data.
final
- onDragEnd → void Function(DragEndDetails)?
-
Callback when node drag ends.
final
- onDragStart → void Function(DragStartDetails)?
-
Callback when node drag starts.
final
- onDragUpdate → void Function(DragUpdateDetails)?
-
Callback when node is dragged.
final
- onTap → VoidCallback?
-
Callback when node is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether the node is selected.
final
- selectionColor → Color?
-
Selection highlight color.
final
- shape → NodeShape
-
Node shape.
final
- showLabel → bool
-
Whether to show the label.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited