OrdinalScale<D, R> class
An ordinal scale maps discrete domain values to discrete range values.
Constructors
-
OrdinalScale({List<
D> ? domain, List<R> ? range, R? unknown}) - Creates an ordinal scale with the given parameters.
Properties
-
domain
↔ List<
D> -
The discrete domain values.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
range
↔ List<
R> -
The discrete range values.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknown ↔ R?
-
The value to return for unknown inputs.
getter/setter pair
Methods
-
call(
D value) → R - Maps a domain value to a range value.
-
copy(
) → OrdinalScale< D, R> - Creates a copy of this scale.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited