PieArc<T> class

Represents a single arc in a pie/donut chart.

Constructors

PieArc({required T data, required double value, required int index, required double startAngle, required double endAngle, required double padAngle})
Creates a pie arc.
const

Properties

angle double
The angular span of the arc.
no setter
data → T
The original data item.
final
endAngle double
The end angle in radians.
final
hashCode int
The hash code for this object.
no setterinherited
index int
The index in the sorted data array.
final
midAngle double
The mid angle of the arc.
no setter
padAngle double
The padding angle in radians.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAngle double
The start angle in radians.
final
value double
The numeric value.
final

Methods

centroid(double innerRadius, double outerRadius) → ({double x, double y})
Calculates the centroid of this arc for the given radii.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited