PointScale<T> class
A point scale maps discrete domain values to points within a continuous range. Similar to band scale but with zero bandwidth.
Constructors
Properties
- align ↔ double
-
The alignment of points within the range (0 to 1).
getter/setter pair
- bandwidth → double
-
The bandwidth is always 0 for point scales.
no setter
-
domain
↔ List<
T> -
The discrete domain values.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding ↔ double
-
The padding on the edges (0 to 1).
getter/setter pair
-
range
↔ List<
double> -
The continuous output range.
getter/setter pair
- round ↔ bool
-
Whether to round output values.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → double
-
Returns the step between points.
no setter
Methods
-
call(
T value) → double - Returns the position of the point for the given value.
-
copy(
) → PointScale< T> - Creates a copy of this scale.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited