ProjectionMixin mixin
Helper for creating projections with common parameters.
- Implemented types
- Mixin applications
Properties
- center ↔ (double, double)
-
The center of the projection
longitude, latitude.getter/setter pairoverride - centerLat → double
-
The center latitude (for use in subclasses).
no setter
- centerLon → double
-
The center longitude (for use in subclasses).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ double
-
The scale factor.
getter/setter pairoverride
- translate ↔ Point
-
The translation offset.
getter/setter pairoverride
Methods
-
applyTransform(
double x, double y) → Point - Applies scale and translation to raw projected coordinates.
-
copy(
) → Projection -
Creates a copy of this projection.
inherited
-
invert(
double x, double y) → (double, double) -
Inverts screen coordinates to geographic
longitude, latitude.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
project(
double longitude, double latitude) → Point -
Projects a geographic coordinate
longitude, latitudeto screen coordinates.inherited -
removeTransform(
double x, double y) → (double, double) - Removes scale and translation from screen coordinates.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited