QuantizeScale<R> class
A quantize scale maps a continuous domain to discrete range values.
Constructors
-
QuantizeScale({List<
double> ? domain, required List<R> range}) - Creates a quantize scale with the given parameters.
Properties
-
domain
↔ List<
double> -
The continuous input domain.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
range
↔ List<
R> -
The discrete output range.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thresholds
→ List<
double> -
Returns the thresholds used for binning.
no setter
Methods
-
call(
double value) → R - Maps a domain value to a range value.
-
copy(
) → QuantizeScale< R> - Creates a copy of this scale.
-
invertExtent(
R value) → (double, double) - Returns the extent of values in the domain that map to the given range value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited