ReferenceLineConfig class

Configuration for a single reference line.

Constructors

ReferenceLineConfig({required Offset start, required Offset end, Color? color, double? width, List<double>? dashPattern, String? label, TextStyle? labelStyle})
const

Properties

color Color?
final
dashPattern List<double>?
final
end Offset
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
labelStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Offset
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited