StackLayout<T> class
Stack layout generator for stacked area/bar charts.
Constructors
-
StackLayout({required List<
String> keys, required double value(T data, String key), StackOrder order = StackOrder.none, StackOffset offset = StackOffset.none}) - Creates a stack layout generator.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
String> -
Keys to stack (series names).
final
- offset → StackOffset
-
The stack offset strategy.
final
- order → StackOrder
-
The stack order strategy.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double Function(T data, String key)
-
Function to extract a value for a given key from a data item.
final
Methods
-
generate(
List< T> data) → List<StackSeries< T> > - Generates stacked series from the given data.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited