StackPoint<T> class
A single point in a stacked series.
Constructors
- StackPoint({required T data, required int index, required double value, required double y0, required double y1})
-
Creates a stack point.
const
Properties
- data → T
-
The original data item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of this segment.
no setter
- index → int
-
The index in the data array.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
The raw value.
final
- y0 → double
-
The lower y bound after stacking.
final
- y1 → double
-
The upper y bound after stacking.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited