Threshold class
Threshold indicator for chart values.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- Threshold
Constructors
-
Threshold({Key? key, required double value, ThresholdDirection direction = ThresholdDirection.horizontal, Color color = Colors.red, double width = 2, List<
double> ? dashPattern, bool showLabel = true, String? label, ThresholdLabelPosition labelPosition = ThresholdLabelPosition.end, TextStyle? labelStyle, Color? labelBackgroundColor, EdgeInsets labelPadding = const EdgeInsets.symmetric(horizontal: 4, vertical: 2), double scale(double value)?}) -
const
Properties
- color → Color
-
Line color.
final
-
dashPattern
→ List<
double> ? -
Line dash pattern (null for solid line).
final
- direction → ThresholdDirection
-
Direction of the threshold line.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Label text (defaults to threshold value).
final
- labelBackgroundColor → Color?
-
Label background color.
final
- labelPadding → EdgeInsets
-
Label padding.
final
- labelPosition → ThresholdLabelPosition
-
Label position.
final
- labelStyle → TextStyle?
-
Label style.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double Function(double value)?
-
Scale function to convert value to position.
final
- showLabel → bool
-
Whether to show the label.
final
- value → double
-
The threshold value.
final
- width → double
-
Line width.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited