ThresholdScale<D extends Comparable<D> , R> class
A threshold scale maps values to discrete outputs based on threshold values.
Constructors
-
ThresholdScale({required List<
D> domain, required List<R> range}) - Creates a threshold scale with the given parameters.
Properties
Methods
-
call(
D value) → R - Maps a domain value to a range value.
-
copy(
) → ThresholdScale< D, R> - Creates a copy of this scale.
-
invertExtent(
R value) → (D?, D?) - Returns the extent of values in the domain that map to the given range value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited