TimeScale class
A time scale maps DateTime values to a continuous range.
Constructors
Properties
- clamp ↔ bool
-
Whether output values are clamped.
getter/setter pair
-
domain
↔ List<
DateTime> -
The input domain of DateTime values.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
range
↔ List<
double> -
The output range.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
DateTime value) → double - Maps a DateTime to a range value.
-
copy(
) → TimeScale - Creates a copy of this scale.
-
invert(
double value) → DateTime - Maps a range value back to a DateTime.
-
nice(
[int count = 10]) → TimeScale - Returns nicely rounded domain values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tickFormat(
[int count = 10]) → String Function(DateTime) - Returns a tick format function.
-
ticks(
[int count = 10]) → List< DateTime> - Returns tick values as DateTime objects.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited