TooltipContent class
A builder widget for creating tooltip content.
TooltipContent provides a structured way to build tooltip content with common patterns like title, value, and description.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TooltipContent
Constructors
-
TooltipContent({Key? key, String? title, String? value, String? description, TextStyle? titleStyle, TextStyle? valueStyle, TextStyle? descriptionStyle, Widget? leading, Widget? trailing, double spacing = 4, List<
Widget> ? children}) -
Creates a TooltipContent widget.
const
-
TooltipContent.fromMap(Map<
String, dynamic> data, {TextStyle? titleStyle, TextStyle? valueStyle, TextStyle? descriptionStyle, String? titleKey = 'title', String? valueKey = 'value', String? descriptionKey = 'description'}) -
Creates a TooltipContent from a map of data.
factory
Properties
-
children
→ List<
Widget> ? -
Custom children to display instead of the structured content.
final
- description → String?
-
Additional description text.
final
- descriptionStyle → TextStyle?
-
The style for the description text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
An optional leading widget (e.g., color indicator).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
The spacing between elements.
final
- title → String?
-
The main title text.
final
- titleStyle → TextStyle?
-
The style for the title text.
final
- trailing → Widget?
-
An optional trailing widget.
final
- value → String?
-
The primary value to display.
final
- valueStyle → TextStyle?
-
The style for the value text.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited