Zoom class
A widget that provides zoom and pan behavior using GestureDetector.
Zoom wraps its child and handles zoom/pan gestures, transforming the child widget according to user interactions.
- Inheritance
Constructors
- Zoom({Key? key, required Widget child, void onZoomChange(ZoomTransform transform)?, void onZoomStart(ZoomTransform transform)?, void onZoomEnd(ZoomTransform transform)?, ZoomTransform? initialTransform, double minScale = 0.1, double maxScale = 10.0, bool panEnabled = true, bool zoomEnabled = true, bool doubleTapZoomEnabled = true, double doubleTapZoomScale = 2.0, bool wheelZoomEnabled = true, double wheelZoomFactor = 0.1, bool constrainPan = false, Rect? panBounds})
-
Creates a Zoom widget.
const
Properties
- child → Widget
-
The child widget to zoom and pan.
final
- constrainPan → bool
-
Whether to constrain panning to bounds.
final
- doubleTapZoomEnabled → bool
-
Whether double-tap to zoom is enabled.
final
- doubleTapZoomScale → double
-
The scale factor for double-tap zoom.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialTransform → ZoomTransform?
-
The initial transform.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxScale → double
-
The maximum scale factor.
final
- minScale → double
-
The minimum scale factor.
final
- onZoomChange → void Function(ZoomTransform transform)?
-
Called when the zoom transform changes.
final
- onZoomEnd → void Function(ZoomTransform transform)?
-
Called when zoom ends.
final
- onZoomStart → void Function(ZoomTransform transform)?
-
Called when zoom starts.
final
- panBounds → Rect?
-
The bounds for panning constraints.
final
- panEnabled → bool
-
Whether panning is enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wheelZoomEnabled → bool
-
Whether mouse wheel zoom is enabled.
final
- wheelZoomFactor → double
-
The scale factor for mouse wheel zoom.
final
- zoomEnabled → bool
-
Whether zooming is enabled.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Zoom> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited